@@ -46,11 +46,15 @@ def force_codec(pc, sender, forced_codec):
 class GSPeerConnectionBroadcasterUniversal:
 
     @classmethod
-    async def create(cls, gsdbs, oncommand=None):
+    async def create(cls, gsdbs, target, videostream=True, addChannel=None, oncommand=None):
         self = GSPeerConnectionBroadcasterUniversal()
         self.rtconfiList = []
         self.gsdbs = gsdbs
+        self.target = target
+        self.videostream = videostream
         self.oncommand = oncommand
+        self.addChannel = addChannel
+
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
         if self.gsdbs.credentials["turnenable"]:
@@ -95,20 +99,24 @@ class GSPeerConnectionBroadcasterUniversal:
                     await pc.close()
                     pcs.discard(pc)
 
-            audio, video = create_local_tracks(False,
-                                               decode=not True,
-                                               device=self.gsdbs.credentials["webcam"],
-                                               rtbufsize=self.gsdbs.credentials["rtbufsize"])
-
             @pc.on("track")
             async def on_track(track):
                 if track.kind == "video":
                     mediablackhole = MediaBlackhole()
                     mediablackhole.addTrack(track)
 
-            if video:
-                video_sender = pc.addTrack(video)
-                force_codec(pc, video_sender, "video/H264")
+            if self.addChannel is not None:
+                sendchannel = pc.createDataChannel("terminatorview")
+                self.addChannel(sendchannel)
+
+            if videostream:
+                audio, video = create_local_tracks(False,
+                                                   decode=not True,
+                                                   device=self.gsdbs.credentials["webcam"],
+                                                   rtbufsize=self.gsdbs.credentials["rtbufsize"])
+                if video:
+                    video_sender = pc.addTrack(video)
+                    force_codec(pc, video_sender, "video/H264")
 
             await pc.setRemoteDescription(offer)
 
@@ -142,5 +150,5 @@ class GSPeerConnectionBroadcasterUniversal:
             connectURL = self.gsdbs.credentials["signalserver"]
 
         await self.sio.connect(
-            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}')
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.target}')
         await self.sio.wait()
