@@ -257,17 +257,19 @@ class FrameBufferThread(Thread):
         self.logger.debug("Starting Buffer")
         self.target = target
         self.onframe = onframe
+        self.framerate = 0
         self.nal_queue = Queue(3)
 
-    def write(self, frame):
+    def write(self, frame, framerate=0):
+        self.framerate = framerate
         if not self.nal_queue.full():
             self.nal_queue.put(frame)
 
     def run(self):
         while True:
             buf = self.nal_queue.get()
-            if buf:
-                self.onframe(self.gsdbs, self.target, buf)
+            if buf is not None or buf:
+                self.onframe(self.gsdbs, self.target, buf, self.framerate)
 
 
 class GSMediaConsumer:
